/*STARTUP(crt0.o)*/
OUTPUT_FORMAT(elf32-m68k)
OUTPUT_ARCH(m68k)
SEARCH_DIR(.)
__DYNAMIC  =  0;

/*
 * Setup the memory map of the Ext336
 *
 * The memory map look like this:
 * +--------------------+ <- low memory
 * | .text              |
 * |        ctor list   | the ctor and dtor lists are for
 * |        dtor list   | C++ support
 * +--------------------+
 * | .data              | initialized data goes here
 * |        _edata      |
 * +--------------------+
 * | .bss               |
 * |        __bss_start | start of bss, cleared by crt0
 * |        _end        | start of heap, used by sbrk()
 * +--------------------+
 * .                    .
 * .                    .
 * .                    .
 * |        __stack     | top of stack
 * +--------------------+
 */
MEMORY
{
  rom     : ORIGIN = 0x000000, LENGTH = 128K
  ramsys  : ORIGIN = 0x120000, LENGTH = 32K
  ramcode : ORIGIN = 0x128000, LENGTH = 96K
  ramdata : ORIGIN = 0x1A0000, LENGTH = 128K
}

/*
 * allocate the stack to be at the top of memory, since the stack
 * grows down
 */
PROVIDE (__stack = 0x1C0000 - 1K);

PROVIDE (ApplStr = 0);
PROVIDE (HelpStr = 0);

/*
 * Initalize some symbols to be zero so we can reference them in the
 * crt0 without core dumping. These functions are all optional, but
 * we do this so we can have our crt0 always use them if they exist. 
 * This is so BSPs work better when using the crt0 installed with gcc.
 * We have to initalize them twice, so we cover a.out (which prepends
 * an underscore) and coff object file formats.
 */
PROVIDE (hardware_init_hook = 0);
PROVIDE (_hardware_init_hook = 0);
PROVIDE (software_init_hook = 0);
PROVIDE (_software_init_hook = 0);

/*
 * Module identity
 * 	"FU" stand alone executable function code
 * 	"PR" SerCom protocol function code
 * 	"TO" SerCom tool function code
 * 	"BI" Bios
 * 	"ST" Start-up code
 * 	"LI" Lib
 * 	"DG" Debug
 * 	"TA" Proc
 */
PROVIDE (idmodule = 0x50525541);

/*
 * File type :
 * 	0 visible in help
 * 	1 executable from SerCom
 * 	2 executable from run
 * 	3 confidential
 */
PROVIDE (fltype = 1);

/*
 * Output type :
 *      0 serial output
 *      1 communication output
 */
PROVIDE (io = 1);

/*
 * stick everything in rom (of course)
 */

SECTIONS
{

 /* Needed for a good computation of the GOT : Size 0 */
 .rela.got      : 
  {
   *(.rela.got)
  } > rom

 _start = .;
 .text : 
  {
    *(.text)
  } > rom

 .rodata BLOCK(0x4) : 
  {
    *(.rodata)
  } > rom

 .gcc_except_table BLOCK(0x4) : 
  {
    *(.gcc_except_table)
  } > rom


 .data BLOCK(0x4) : 
  {
    *(.data)
  } > rom

 .ctors BLOCK(0x4) : 
  {
    __CTOR_LIST__ = .;
    *(.ctors)
    __CTOR_END__ = .;
  } > rom

 .dtors BLOCK(0x4) : 
  {
    __DTOR_LIST__ = .;
    *(.dtors)
    __DTOR_END__ = .;
  } > rom

 /* Global offset table for position independent code generation */
 /* Outside Section Data : better computation */
 .got : 
  {
   *(.got.plt)
   *(.got)
  } > rom

 .bss BLOCK (0x8) :
  {
   __bss_start = . ;
    *(.bss)
    *(COMMON)
    __bss_end =  .;
  } > rom

 _end =  ALIGN (0x8);

  /* Computation of symbols used for the KTEAM Header */

  ptrrom = _start;
  lnrom = _end - _start;
  ptrram = 0x1A0000;
  /* End of memory - size of stack - end of program */
  /* Also used in sbrk (i.e. malloc) */
  lnram = __stack - 1K - ptrram;

}
