#include <stdio.h>
#include <sys/kos.h>
#include <sys/ktdebug.h>


/************************ TEST **************************/

uint8 handler1, handler2[2], handler3, handler4, handler5, handler6;
uint32 delay;

static void
process1 ()
{
  uint8 v = 0;			/* v=0 */
  KTdebug_setAutoWatch (handler1, (void *) &v);
  for (;;)			/* endless loop */
    {
      tim_suspend_task (delay);	/* Wait delay ms */
      v ^= 1;			/* not v */
      ((v) ? var_on_led (0) : var_off_led (0));	/* v -> LED0 */
    }
}

static void
process2 ()
{
  uint8 v = 0;
  uint16 v16 = 0;
  for (;;)			/* Endless loop */
    {
      tim_suspend_task (50);	/* Wait x0ms */
      v++;			/* v++ */
      v16++;
      if (v > 255)		/* if v overflow */
	v = 0;			/* reset v */
      if (v16 > 65535)
	v16 = 0;
      KTdebug_update (handler2[1], (void *) &v16);	/* send v to PC */
      KTdebug_update (handler2[0], (void *) &v);	/* send v to PC */
    }
}

static void
process3 ()
{
  uint8 vars[5];
  vars[0] = 0;
  vars[1] = 1;
  vars[2] = 2;
  vars[3] = 3;
  vars[4] = 4;
  KTdebug_setAutoWatch (handler3, (void *) vars);
  for (;;)
    {
      vars[0]++;
      vars[1] += 2;
      vars[2] += 4;
      vars[3] += 6;
      vars[4] += 12;
      /*KTdebug_update( handler3, (void*)vars ); */
      tim_suspend_task (1000);
    }
}

static void
process4 ()
{
  IRSENSOR *ptr = sens_get_pointer ();	/* get pointer to sensor field */

  for (;;)			/* endless loop */
    {
      tim_wait_sync (1 << KSENSStartSweep);	/* Wait for sensors to updated */
      KTdebug_update (handler4, (void *) ptr);	/* signalize to debug that new values */
    }
}

static void
button_callBack (int d)
{
  var_change_led (1);
}

static void
value_callBack (int d)
{
  delay = d;
}

int
main ()
{
  static char prName_1[] =
    "User 1 process, EF-98                            Rev. 1.00\r\n";
  static char prName_2[] =
    "User 2 process, EF-98                            Rev. 1.00\r\n";
  static char prName_3[] =
    "User 3 process, EF-98                            Rev. 1.00\r\n";
  static char prName_4[] =
    "User 4 process, EF-98                            Rev. 1.00\r\n";

  bios_reset ();
  tim_reset ();
  sens_reset ();
  var_reset ();
  delay = 500;

  printf ("KTdebug_init\n");
  KTdebug_init ();

  printf ("TestToggle\n");
  handler1 = KTdebug_addWatch_Boolean ("TestToggle");
  install_task (prName_1, 1800, process1);

  printf ("Freesbee & Hoolahoop variable\n");
  handler2[0] =
    KTdebug_addWatch_Integer ("Freesbee", MODE_SLIDER | MODE_HEXA, 1, TRUE);	/* declare variable v */
  handler2[1] =
    KTdebug_addWatch_Integer ("Hoolahoop", MODE_SLIDER | MODE_DECIMAL, 2, TRUE);	/* declare variable v */
  install_task (prName_2, 1800, process2);

  printf ("Ataru variable\n");
  handler3 =
    KTdebug_addWatch_Array ("Ataru", MODE_SLIDER | MODE_DECIMAL, 5,
			    (struct VarArrayDesc[])
			    {
			    {
			    -1, 'a'}
			    ,
			    {
			    -1, 'b'}
			    ,
			    {
			    -1, 'c'}
			    ,
			    {
			    -1, 'd'}
			    ,
			    {
			    -1, 'e'}
			    }
  );
  install_task (prName_3, 1800, process3);

  printf ("Sens Array\n");
  handler4 =
    KTdebug_addWatch_ArraySingleType ("Sens", MODE_DECIMAL | MODE_SLIDER,
				      8, -2, "01234567", 0, 1024);
  install_task (prName_4, 1800, process4);

  printf ("Houba Button\n");
  handler5 = KTdebug_addActor_Button ("Houba", button_callBack);
  handler6 =
    KTdebug_addActor_Value ("Valeur", MODE_SLIDER | MODE_DECIMAL, delay, 400,
			    10000, value_callBack);
  return 0;
}
